# Security Considerations on the design of HDP Declarative Programming syntax

> hdp-conventions/security-considerations.md is an early draft. Even (as would
  be expected with any project, so even more for something as necessarily
  complex as the problem this is trying to solve) this gets used without
  renaming or be base for future work, it could take years for a project to be
  ready for formal security auditing. (Emerson Rocha, 2021-04-04 20:22)

> draft